@@ -78,12 +78,15 @@ var menudata={children:[
 {text:"File List",url:"files.html"},
 {text:"File Members",url:"globals.html",children:[
 {text:"All",url:"globals.html",children:[
-{text:"j",url:"globals.html#index_j"},
+{text:"f",url:"globals.html#index_f"},
+{text:"j",url:"globals_j.html#index_j"},
+{text:"k",url:"globals_k.html#index_k"},
 {text:"t",url:"globals_t.html#index_t"}]},
 {text:"Functions",url:"globals_func.html",children:[
 {text:"j",url:"globals_func.html#index_j"}]},
 {text:"Typedefs",url:"globals_type.html"},
 {text:"Enumerations",url:"globals_enum.html"},
 {text:"Enumerator",url:"globals_eval.html",children:[
-{text:"j",url:"globals_eval.html#index_j"}]},
+{text:"j",url:"globals_eval.html#index_j"},
+{text:"k",url:"globals_eval.html#index_k"}]},
 {text:"Macros",url:"globals_defs.html"}]}]}]}
